@@ -1,7 +1,7 @@
 #' Get Shark Column Example
 #'
 #' This function reads a SHARK submission example from a file included in the package.
-#' This format is used for submitting IFCB data to \url{https://shark.smhi.se/}.
+#' This format is used for submitting IFCB data to \url{https://shark.smhi.se/en/}.
 #'
 #' @return A data frame containing example data following the SHARK submission format.
 #' @export
@@ -12,11 +12,11 @@
 #' shark_example <- ifcb_get_shark_example()
 #'
 #' # Print example as tibble
-#' dplyr::tibble(shark_example)
+#' print(shark_example)
 ifcb_get_shark_example <- function() {
-  shark_example <- read.table(system.file("exdata/shark_col.txt", package = "iRfcb"),
-                              sep = "\t",
-                              header = TRUE)
+  shark_example <- read_tsv(system.file("exdata/shark_col.txt", package = "iRfcb"),
+                            show_col_types = FALSE,
+                            progress = FALSE)
 
   shark_example$DATE_TIME <- as.character(shark_example$DATE_TIME)
 
